@@ -1,7 +1,7 @@
 package Sah::Schemas::WordList;
 
-our $DATE = '2020-05-27'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-06-07'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas related to WordList
@@ -18,7 +18,13 @@ Sah::Schemas::WordList - Sah schemas related to WordList
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::WordList (from Perl distribution Sah-Schemas-WordList), released on 2020-05-27.
+This document describes version 0.003 of Sah::Schemas::WordList (from Perl distribution Sah-Schemas-WordList), released on 2021-06-07.
+
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (on netbook-dell-xps13)
+
+perlancar (on netbook-dell-xps13) <perlancar@gmail.com>
 
 =head1 HOMEPAGE
 
@@ -50,7 +56,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
